pub enum DerivedComponent {
Authority {
req: bool,
},
TargetUri {
req: bool,
},
RequestTarget {
req: bool,
},
Method {
req: bool,
},
Path {
req: bool,
},
Scheme {
req: bool,
},
Query {
req: bool,
},
QueryParams {
parameters: QueryParamParametersSet,
},
Status {
req: bool,
},
}Expand description
A list of derived components, used to specify attributes of an HTTP message that otherwise can’t be referenced
via an HTTP header but nevertheless can be used in generating a signature base. Each component here, with the sole
exception of QueryParameters, accepts a single component parameter `req.
Variants
Authority
Represents @authority derived component
Fields
TargetUri
Represents @target-uri derived component
Fields
RequestTarget
Represents @request-target derived component
Fields
Method
Represents @method derived component
Fields
Path
Represents @path derived component
Fields
Scheme
Represents @scheme derived component
Fields
Query
Represents @query derived component
Fields
QueryParams
Represents the @query-params derived component
Fields

parameters: QueryParamParametersSetThe list of parameters associated with this field
Status
Represents @status derived component