Enum WebBotAuthError
Source pub enum WebBotAuthError {
SignatureIsExpired,
}
Errors thrown when verifying a Web Bot Auth-signed message specifically.
Thrown when the signature is detected to be expired, using the expires
and creates method.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.