pub enum KeyringError {
UnsupportedAlgorithm,
ParsingError(DecodeError),
ConversionError(Error),
KeyAlreadyExists,
}Expand description
Errors that may be thrown by this module when importing a JWK key.
Variants
UnsupportedAlgorithm
JWK key specified an unsupported algorithm
ParsingError(DecodeError)
The contained parameters could not be parsed correctly
ConversionError(Error)
The bytes found could not be cast to a valid public key
KeyAlreadyExists
The key already exists in our keyring