Thumbprintable

Enum Thumbprintable 

pub enum Thumbprintable {
    EC {
        crv: String,
        x: String,
        y: String,
    },
    OKP {
        crv: String,
        x: String,
    },
    RSA {
        e: String,
        n: String,
    },
    OCT {
        k: String,
    },
}
Represents a JSON Web Key containing the bare minimum that can be thumbprinted per RFC 7638

Variants



EC

An elliptic curve key

Fields

crv: String

Corresponding crv

x: String

Corresponding x

y: String

Corresponding y



OKP

An OKP key, supporting Ed25519 keys

Fields

crv: String

Corresponding crv

x: String

Corresponding x



RSA

An RSA key

Fields

e: String

Corresponding e

n: String

Corresponding n



OCT

A symmetric key

Fields

k: String

Corresponding k

Implementations

Source

impl Thumbprintable

pub fn b64_thumbprint(&self) -> String

Calculate the base64-encoded URL safe JWK thumbprint associated with the key

pub fn public_key(&self) -> Result<Vec<u8>, KeyringError>

Attempt to cast into a public key.

Errors

Today we only support importing ed25519 keys. Errors may be thrown when decoding or converting the JSON web key into an ed25519 public key.

pub fn algorithm(&self) -> Result<Algorithm, KeyringError>

Attempt to extract algorithm.

Errors

Today we only support extracting the algorithm of an ed25519 key.