pub struct ParameterDetails {
pub algorithm: Option<Algorithm>,
pub created: Option<i64>,
pub expires: Option<i64>,
pub keyid: Option<String>,
pub nonce: Option<String>,
pub tag: Option<String>,
}Expand description
Parsed values from Signature-Input header.
Fields
algorithm: Option<Algorithm>The value of the alg parameter, if present and resolves to a known algorithm.
created: Option<i64>The value of the created parameter, if present.
expires: Option<i64>The value of the expires parameter, if present.
keyid: Option<String>The value of the keyid parameter, if present.
nonce: Option<String>The value of the nonce parameter, if present.
tag: Option<String>The value of the tag parameter,if present.
Implementations
Sourceimpl ParameterDetails
impl ParameterDetails
Sourcepub fn possibly_insecure<F>(&self, nonce_validator: F) -> SecurityAdvisory
pub fn possibly_insecure<F>(&self, nonce_validator: F) -> SecurityAdvisory
Indicates whether or not the message has semantic errors
that suggest the message should not be verified on account of posing
a security risk. nonce_validator should return true if the nonce is
invalid, and false otherwise.