pub struct ParsedLabel {
pub label: Key,
pub signature: Vec<u8>,
pub base: SignatureBase,
}Expand description
A parsed representation of the signature and the components chosen to cover that
signature, once MessageVerifier has parsed the message. This allows inspection
of the chosen labl and its components.
Fields
label: KeyThe label that was chosen.
signature: Vec<u8>The signature obtained from the message that verifiers will verify
base: SignatureBaseThe signature base obtained from the message, containining both the chosen components to cover as well as any interesting parameters of the same.