pub struct SecurityAdvisory {
pub is_expired: Option<bool>,
pub nonce_is_invalid: Option<bool>,
}Expand description
Advises whether or not to accept the message as valid prior to verification, based on a cursory examination of the message parameters.
Fields
is_expired: Option<bool>If the expires tag was present on the message, whether or not
the message expired in the past.
nonce_is_invalid: Option<bool>If the nonce tag was present on the message, whether or not
the nonce was valid, as judged py a suitable nonce validator.