Struct MessageSigner

pub struct MessageSigner {
    pub algorithm: Algorithm,
    pub keyid: String,
    pub nonce: String,
    pub tag: String,
}
A struct that implements signing. The struct fields here are serialized into the Signature-Input header.

Fields

algorithm: Algorithm

Algorith mto use for signing

keyid: String

Name to use for keyid parameter

nonce: String

A random nonce to be provided for additional security

tag: String

Value to be used for tag parameter

Implementations

Source

impl MessageSigner

pub fn generate_signature_headers_content( &self, message: &mut impl UnsignedMessage, expires: Duration, signing_key: &PublicKey, ) -> Result<(), ImplementationError>

Sign the provided method with signing_key, setting an expiration value of length expires from now (the time of signing).

Errors

Returns ImplementationErrors relevant to signing and parsing.