Trait SignedMessage

pub trait SignedMessage {
    // Required methods
    fn fetch_signature_header(&self) -> Option<String>;
    fn fetch_signature_input(&self) -> Option<String>;
    fn lookup_component(&self, name: &CoveredComponent) -> Option<String>;
}
Trait that messages seeking verification should implement to facilitate looking up raw values from the underlying message.

Required Methods

fn fetch_signature_header(&self) -> Option<String>

Obtain the parsed version of Signature HTTP header

fn fetch_signature_input(&self) -> Option<String>

Obtain the parsed version of Signature-Input HTTP header

fn lookup_component(&self, name: &CoveredComponent) -> Option<String>

Obtain the serialized value of a covered component. Implementations should respect any parameter values set on the covered component per the message signature spec. Component values that cannot be found must return None. CoveredComponent::HTTP fields are guaranteed to have lowercase ASCII names, so care should be taken to ensure HTTP field names in the message are checked in a case-insensitive way.

Implementors