Type Alias KeyRing

pub type KeyRing = HashMap<Thumbprint, PublicKey>;
A map from a thumbprint to the public key, to be used to map keyids to public keys.

Aliased Type

pub struct KeyRing { /* private fields */ }