pub enum Thumbprintable {
EC {
crv: String,
x: String,
y: String,
},
OKP {
crv: String,
x: String,
},
RSA {
e: String,
n: String,
},
OCT {
k: String,
},
}Expand description
Represents a JSON Web Key containing the bare minimum that can be thumbprinted per RFC 7638
Variants
Implementations
Sourceimpl Thumbprintable
impl Thumbprintable
Sourcepub fn b64_thumbprint(&self) -> String
pub fn b64_thumbprint(&self) -> String
Calculate the base64-encoded URL safe JWK thumbprint associated with the key
Sourcepub fn public_key(&self) -> Result<Vec<u8>, KeyringError>
pub fn public_key(&self) -> Result<Vec<u8>, KeyringError>
Attempt to cast into a public key.
Errors
Today we only support importing ed25519 keys. Errors may be thrown when decoding or converting the JSON web key into an ed25519 public key.